Yews | Your Earthquake Waveform Solution
========================================

Yews is a deep learning toolbox for processing seismic waveform made with flexibility, speed, and usability in mind. It is built upon `PyTorch <https://github.com/pytorch/pytorch>`_ and `ObsPy <https://github.com/obspy/obspy>`_ for researchers interested in applying deep learning techniques on seismic waveform data.

Installation
============

From source:

.. code:: bash

    python setup.py install

Documentation
=============

Under construction.

Contributing
============

We appreciate all contributions. If you are planning to contribute back bug-fixes, please do so without any further discussion. If you plan to contribute new features, utility functions or extensions, please first open an issue and discuss the feature with us.

